from django.db import models
from wagtail.core.models import Page
from wagtail.core.fields import StreamField

from wagtail_color_panel.fields import ColorField
from wagtail_color_panel.edit_handlers import NativeColorPanel
from wagtail_color_panel.blocks import NativeColorBlock


class PageWithColorField(Page):
    color = ColorField()

    content_panels = Page.content_panels + [
        NativeColorPanel('color'),
    ]


class PageWithCharColorField(Page):
    color = models.CharField(max_length=7)


class PageWithDefaultValue(Page):
    color = ColorField(default="#FF0000")


class PageWithStreamfield(Page):
    body = StreamField([
        ('color', NativeColorBlock()),
    ])



from wagtail.admin.edit_handlers import FieldPanel

from wagtail_color_panel.widgets import ColorInputWidget


class NativeColorPanel(FieldPanel):
    def widget_overrides(self):
        return {
            self.field_name: ColorInputWidget(),
        }



from django.forms import widgets, Media
from wagtail.admin.staticfiles import versioned_static


class ColorInputWidget(widgets.Input):
    input_type = "color"

    def __init__(self, attrs=None):
        default_attrs = {"class": "color-input-widget"}
        attrs = attrs or {}
        attrs = {**default_attrs, **attrs}
        super().__init__(attrs=attrs)

    # def get_panel(self):
    #     from wagtail_color_panel.edit_handlers import NativeColorPanel
    #     return NativeColorPanel

    @property
    def media(self):
        return Media(
            css={
                "all": [
                    versioned_static("wagtail_color_panel/css/color-input-widget.css"),
                ]
            }
        )



# Generated by Django 3.0.7 on 2020-07-31 06:52

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.fields
import wagtail_color_panel.blocks
import wagtail_color_panel.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0052_pagelogentry'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageWithCharColorField',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('color', models.CharField(max_length=7)),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='PageWithColorField',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('color', wagtail_color_panel.fields.ColorField(max_length=7)),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='PageWithDefaultValue',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('color', wagtail_color_panel.fields.ColorField(default='#FF0000', max_length=7)),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
        migrations.CreateModel(
            name='PageWithStreamfield',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.Page')),
                ('body', wagtail.core.fields.StreamField([('color', wagtail_color_panel.blocks.NativeColorBlock())])),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]
